#!/bin/bash
# 13) Personaliación de nuevos lanzadores:

function crear_lanzadores() {
    PARAM="${1}"
    CONT="${2}"
    # Rescatamos los parametros del comando a ejecutar /usr/bin/vx-conf-lanzadores-desktop:
    LANZADOR="$(jq -r ".${PARAM}[${CONT}].lanzador" <<<"${JSON}")"
    NAME="$(jq -r ".${PARAM}[${CONT}].name" <<<"${JSON}")"
    NAME_ES="$(jq -r ".${PARAM}[${CONT}].name_es" <<<"${JSON}")"
    COMENTARIO="$(jq -r ".${PARAM}[${CONT}].comment" <<<"${JSON}")"
    COMENTARIO_ES="$(jq -r ".${PARAM}[${CONT}].comment_es" <<<"${JSON}")"
    EXEC="$(jq -r ".${PARAM}[${CONT}].exec" <<<"${JSON}")"
    # Logo SVG guardado normalmente en: /usr/share/icons/hicolor/scalable/apps/
    LOGO_DESK="$(jq -r ".${PARAM}[${CONT}].icon" <<<"${JSON}")"
    CATEGORIAS="$(jq -r ".${PARAM}[${CONT}].categories" <<<"${JSON}")"
    EN_ESCRITORIOS="$(jq -r ".${PARAM}[${CONT}].lanzador_en_Escritorios" <<<"${JSON}")"
    UIDS="$(jq -r ".${PARAM}[${CONT}].uids" <<<"${JSON}")"
    GIDS="$(jq -r ".${PARAM}[${CONT}].gids" <<<"${JSON}")"
    # Comprobas si es necesario enviar un PATH del ejecutable (ej. los ejecutables lanzadores de los ebooks de oxford)
    PATHEXE="$(jq -r ".${PARAM}[${CONT}].path" <<<"${JSON}")"
    # Comprobamos si se ha indicado el agrupar en un directorio los lanzadores. Valdrá "null" si no se ha definido:
    [[ "$(jq -r ".${PARAM}[${CONT}].agrupado_en_dir" <<<"${JSON}")" =~ ^null$|^false$ ]] &&
        AGRUPADO_EN_DIR="false" ||
        AGRUPADO_EN_DIR="true"
    NOMBRE_DIR="$(jq -r ".${PARAM}[${CONT}].nombre_dir" <<<"${JSON}")"

    if vx-conf-lanzadores-desktop --crear "${LANZADOR}" \
        "${NAME}" \
        "${NAME_ES}" \
        "${COMENTARIO}" \
        "${COMENTARIO_ES}" \
        "${EXEC}" \
        "${LOGO_DESK}" \
        "${CATEGORIAS}" \
        "${EN_ESCRITORIOS}" \
        "${UIDS}" \
        "${GIDS}" \
        "${AGRUPADO_EN_DIR}" \
        "${NOMBRE_DIR}" \
        "${PATHEXE}"; then
        "${echo_verde}" "=> ¡¡Ok!! Se ha creado el lanzador correctamente: ${LANZADOR}"
    else
        "${echo_rojo}" "=> ¡¡Error!! Problemas para crear el lanzador: ${LANZADOR}"
    fi
}

function borrar_lanzadores() {
    PARAM="${1}"
    CONT="${2}"
    # Rescatamos los parametros del comando a ejecutar /usr/bin/vx-conf-lanzadores-desktop:
    LANZADORES="$(jq -r ".${PARAM}[${CONT}].lanzador" <<<"${JSON}")"
    LISTA_LANZADORES=(${LANZADORES//;/ })
    # Comprobamos si se ha indicado el agrupar en un directorio los lanzadores. Valdrá "null" si no se ha definido:
    [[ "$(jq -r ".${PARAM}[${CONT}].agrupado_en_dir" <<<"${JSON}")" =~ ^null$|^false$ ]] &&
        AGRUPADO_EN_DIR="false" ||
        AGRUPADO_EN_DIR="true"
    NOMBRE_DIR="$(jq -r ".${PARAM}[${CONT}].nombre_dir" <<<"${JSON}")"
    for LANZADOR in "${LISTA_LANZADORES[@]}"; do
        if vx-conf-lanzadores-desktop --borrar "${LANZADOR}" "${AGRUPADO_EN_DIR}" "${NOMBRE_DIR}"; then
            "${echo_verde}" "=> ¡¡Ok!! Se ha borrado el lanzador correctamente: ${LANZADOR}"
        else
            "${echo_rojo}" "=> ¡¡Error!! Problemas para borrar el lanzador: ${LANZADOR}"
        fi
    done
}

function copiar_lanzadores() {
    PARAM="${1}"
    CONT="${2}"
    # Rescatamos los parametros del comando a ejecutar /usr/bin/vx-conf-lanzadores-desktop:
    LANZADORES="$(jq -r ".${PARAM}[${CONT}].lanzador" <<<"${JSON}")"
    LISTA_LANZADORES=(${LANZADORES//;/ })
    # Comprobamos si se ha indicado agrupar los lanzadores a copiar en un directorio. Valdrá "null" si no se ha definido:
    [[ "$(jq -r ".${PARAM}[${CONT}].agrupado_en_dir" <<<"${JSON}")" =~ ^null$|^false$ ]] &&
        AGRUPADO_EN_DIR="false" ||
        AGRUPADO_EN_DIR="true"
    NOMBRE_DIR="$(jq -r ".${PARAM}[${CONT}].nombre_dir" <<<"${JSON}")"
    for LANZADOR in "${LISTA_LANZADORES[@]}"; do
        if vx-conf-lanzadores-desktop --copiar "${LANZADOR}" "${AGRUPADO_EN_DIR}" "${NOMBRE_DIR}" ; then
            "${echo_verde}" "=> ¡¡Ok!! Se ha copiado el lanzador correctamente: ${LANZADOR}"
        else
            "${echo_rojo}" "=> ¡¡Error!! Problemas para copiar el lanzador: ${LANZADOR}"
        fi
    done
}

"${echo_titulo}" "*  [[ Borrar Lanzadores especifícos de Centro ... ]]  *"
PARAM="lanzadoresespecificos.borrar.lista"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Borrar Lanzadores Específicos" "borrar_lanzadores"

"${echo_titulo}" "*  [[ Crear Lanzadores especifícos de Centro ... ]]  *"
PARAM="lanzadoresespecificos.crear.lista"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Crear Lanzadores Específicos" "crear_lanzadores"

"${echo_titulo}" "*  [[ Copiar Lanzadores solicitados por el centro ... ]]  *"
PARAM="lanzadoresespecificos.copiar.lista"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Copiar Lanzadores Específicos" "copiar_lanzadores"
