#!/bin/bash
# 81) Ejecutar Tareas Programadas de personalización del centro:

function crear_fichini() {
    SECCION="${1}"
    if ! crudini --get "${FICHINI}" "${SECCION}" >/dev/null 2>&1; then
        crudini --set "${FICHINI}" "${SECCION}" &&
        echo "=> ${FICHINI}: Se ha creado la sección: ${SECCION}"
    else
        echo "=> ${FICHINI}: Ya existe la sección: ${SECCION}"
    fi
    until [[ -z "${1}" ]]; do
        CLAVE="${1/=*/}"
        VALOR="${1/*=/}"
        if ! VARLORINI="$(crudini --get "${FICHINI}" "${SECCION}" "${CLAVE}" 2>/dev/null)"; then
            crudini --set "${FICHINI}" "${SECCION}" "${CLAVE}" "${VALOR}" &&
            echo "=> ${FICHINI}: Se ha insertado ${CLAVE}:${VALOR}"
        else
            echo "=> ${FICHINI}: Ya existen ${CLAVE}:${VARLORINI}"
        fi
        shift
    done
}

function ejecutar_tarea() {
    PARAM="${1}"
    CONT="${2}"
    # Rescatamos el comando a ejecutar y lo lanzamos:
    FICHINI="$(jq -r ".${PARAM}[${CONT}].fichini" <<<"${JSON}")"
    DESC="$(jq -r ".${PARAM}[${CONT}].desc" <<<"${JSON}")"
    SECCION="$(jq -r ".${PARAM}[${CONT}].section" <<<"${JSON}")"
    FECHAINI="$(jq -r ".${PARAM}[${CONT}].fechaini" <<<"${JSON}")"
    FECHAFIN="$(jq -r ".${PARAM}[${CONT}].fechafin" <<<"${JSON}")"
    NVECES="$(jq -r ".${PARAM}[${CONT}].nveces" <<<"${JSON}")"
    TAREA="$(jq -r ".${PARAM}[${CONT}].tarea" <<<"${JSON}")"
    # fechaset y nvecesejecutada serán null y 0 por defecto:
    [[ ! -f "${FICHINI}" ]] &&
    echo "=> No existe el archivo de variables de configuración de centro: ${FICHINI}" &&
    echo "=> Vamos a crear: ${FICHINI}" && touch "${FICHINI}"
    crear_fichini "${SECCION}" "desc=${DESC}" \
    "fechaini=${FECHAINI}" "fechafin=${FECHAFIN}" "fechaset=null" \
    "nveces=${NVECES}" "nvecesejecutada=0"
    
    # Hacemos cálculos con fechas tipo unix-timestamps (segundos desde 1.1.1970 0:0:0) para saber si toca ejecutar la tarea:
    TODAY="$(date "+%Y-%m-%d %H:%M:%S")"
    TODAYMS="$(date -d "${TODAY}" "+%s")"
    # FECHAINI=$(crudini --get "${FICHINI}" "${SECCION}" "fechaini")
    FECHAINIMS="$(date -d "${FECHAINI}" "+%s")"
    [[ ${TODAYMS} -lt ${FECHAINIMS} ]] &&
    echo "=> No ha llegado el día para ejecutar la tarea programada ${TAREA}: ${TODAY} < ${FECHAINI}" &&
    return 0
    # Comprobamos la fecha final para la ejecución de la tarea:
    # FECHAFIN=$(crudini --get "${FICHINI}" "${SECCION}" "fechafin")
    if [[ "${FECHAFIN}" != "null" ]]; then
        FECHAFINMS="$(date -d "${FECHAFIN}" "+%s")"
        [[ ${TODAYMS} -gt ${FECHAFINMS} ]] &&
        echo "=> Ha pasado el intérvalo de días para ejecutar la tarea programada ${TAREA}: ${TODAY} > ${FECHAFIN}" &&
        return 0
    fi
    
    # Comprobamos si la tarea se ha ejecutado previamente para no volverla a ejectutar, en caso de que no deba ejecutarse multiples veces:
    # Comprobamos si ya se ha realizado la acción comprobando fechaset, y el numero de veces que debe ejecutarse con nveces y nvecesejecutada:
    FECHASET="$(crudini --get "${FICHINI}" "${SECCION}" "fechaset")"
    NVECESEJECUTADA="$(crudini --get "${FICHINI}" "${SECCION}" "nvecesejecutada")"
    [[ "${NVECES}" != "all" ]] &&
    ([[ "${FECHASET}" != "null" ]] && [[ "${NVECES}" == "null" || "${NVECESEJECUTADA}" -gt "${NVECES}" ]]) &&
    echo "=> Ya se ejecutó la tarea programada ${TAREA}: ${FECHASET}" &&
    return 0
    
    # Ejecutamos la tarea:
    TAREAOK="false"
    if eval "${TAREA}"; then
        TAREAOK="true"
        "${echo_verde}" "=> ¡¡Ok!! Tarea programada configurada correctamente: ${TAREA}:${FECHAINI}:${FECHAFIN}"
    else
        "${echo_rojo}" "=> ¡¡Error!! Problemas para configurar la tarea programada: ${TAREA}:${FECHAINI}:${FECHAFIN}"
    fi
    
    # Asignamos fechaset para indicar que se ha ejecutado la acción:
    "${TAREAOK}" &&
    crudini --set "${FICHINI}" "${SECCION}" "fechaset" "${TODAY}" &&
    crudini --set "${FICHINI}" "${SECCION}" "nvecesejecutada" "$((NVECESEJECUTADA + 1))" &&
    return 0
    return 1
}

"${echo_titulo}" "*  [[ Tareas Programadas de personalización del Centro ... ]]  *"
PARAM="tareasprogramadas.lista"
# check_parametro [parametro] [breve descripción] [función a llamar]
check_parametro "${PARAM}" "Tareas Programadas" "ejecutar_tarea"
